from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Student(_message.Message):
    __slots__ = ["assign_all", "assignments", "graded_at", "grades", "id", "inactive", "member_id", "overall_grade", "overall_progress", "updated_at", "url"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Assignment(_message.Message):
        __slots__ = ["assigned_at", "complete_before", "completed_at", "duration", "grades", "module_id", "overall_grade", "overall_progress", "start_after", "started_at", "status"]
        ASSIGNED_AT_FIELD_NUMBER: _ClassVar[int]
        COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
        COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
        DURATION_FIELD_NUMBER: _ClassVar[int]
        GRADES_FIELD_NUMBER: _ClassVar[int]
        MODULE_ID_FIELD_NUMBER: _ClassVar[int]
        OVERALL_GRADE_FIELD_NUMBER: _ClassVar[int]
        OVERALL_PROGRESS_FIELD_NUMBER: _ClassVar[int]
        STARTED_AT_FIELD_NUMBER: _ClassVar[int]
        START_AFTER_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        assigned_at: _timestamp_pb2.Timestamp
        complete_before: _timestamp_pb2.Timestamp
        completed_at: _timestamp_pb2.Timestamp
        duration: int
        grades: _containers.RepeatedCompositeFieldContainer[Student.Grade]
        module_id: str
        overall_grade: int
        overall_progress: float
        start_after: _timestamp_pb2.Timestamp
        started_at: _timestamp_pb2.Timestamp
        status: Student.Status
        def __init__(self, module_id: _Optional[str] = ..., status: _Optional[_Union[Student.Status, str]] = ..., overall_progress: _Optional[float] = ..., overall_grade: _Optional[int] = ..., assigned_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., grades: _Optional[_Iterable[_Union[Student.Grade, _Mapping]]] = ...) -> None: ...
    class Grade(_message.Message):
        __slots__ = ["entry_id", "grade", "progress"]
        ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
        GRADE_FIELD_NUMBER: _ClassVar[int]
        PROGRESS_FIELD_NUMBER: _ClassVar[int]
        entry_id: str
        grade: int
        progress: float
        def __init__(self, entry_id: _Optional[str] = ..., progress: _Optional[float] = ..., grade: _Optional[int] = ...) -> None: ...
    ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    ASSIGN_ALL_FIELD_NUMBER: _ClassVar[int]
    BLOCKED: Student.Status
    BREAKDOWN: Student.Extra
    COMPLETED: Student.Status
    GRADED_AT_FIELD_NUMBER: _ClassVar[int]
    GRADES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    OVERALL_GRADE_FIELD_NUMBER: _ClassVar[int]
    OVERALL_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    PENDING: Student.Status
    READY: Student.Status
    STARTED: Student.Status
    UNASSIGNED: Student.Status
    UNKNOWN_EXTRA: Student.Extra
    UNKNOWN_STATUS: Student.Status
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    assign_all: bool
    assignments: _containers.RepeatedCompositeFieldContainer[Student.Assignment]
    graded_at: _timestamp_pb2.Timestamp
    grades: _containers.RepeatedCompositeFieldContainer[Student.Grade]
    id: str
    inactive: bool
    member_id: str
    overall_grade: int
    overall_progress: float
    updated_at: _timestamp_pb2.Timestamp
    url: str
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., member_id: _Optional[str] = ..., inactive: bool = ..., assign_all: bool = ..., overall_progress: _Optional[float] = ..., overall_grade: _Optional[int] = ..., grades: _Optional[_Iterable[_Union[Student.Grade, _Mapping]]] = ..., assignments: _Optional[_Iterable[_Union[Student.Assignment, _Mapping]]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., graded_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from .entry_service_http import *
from .problem_service_pb2 import *
from .entry_service_pb2 import *
from .entry_video_pb2 import *
from .student_service_http import *
from .assignment_item_v2_pb2 import *
from .assignment_v2_pb2 import *
from .module_item_pb2 import *
from .student_service_pb2 import *
from .module_pb2 import *
from .module_item_service_pb2 import *
from .entry_section_pb2 import *
from .course_service_http import *
from .student_pb2 import *
from .module_service_pb2 import *
from .assignment_service_v2_http import *
from .problem_service_http import *
from .assignment_service_pb2 import *
from .course_service_pb2 import *
from .module_item_service_http import *
from .entry_pb2 import *
from .entry_problem_pb2 import *
from .assignment_pb2 import *
from .assignment_service_http import *
from .course_pb2 import *
from .assignment_service_v2_pb2 import *
from .module_service_http import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import deprecated_report_pb2 as eolymp_dot_executor_dot_deprecated__report__pb2
from eolymp.executor import status_pb2 as eolymp_dot_executor_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/executor/events.proto\x12\x0f\x65olymp.executor\x1a\'eolymp/executor/deprecated_report.proto\x1a\x1c\x65olymp/executor/status.proto\"=\n\x12StatusUpdatedEvent\x12\'\n\x06status\x18\x01 \x01(\x0b\x32\x17.eolymp.executor.Status\";\n\x10JobReportedEvent\x12\'\n\x06report\x18\x01 \x01(\x0b\x32\x17.eolymp.executor.ReportB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _STATUSUPDATEDEVENT._serialized_start=120
  _STATUSUPDATEDEVENT._serialized_end=181
  _JOBREPORTEDEVENT._serialized_start=183
  _JOBREPORTEDEVENT._serialized_end=242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/assignment_service_v2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import assignment_item_v2_pb2 as eolymp_dot_course_dot_assignment__item__v2__pb2
from eolymp.course import assignment_v2_pb2 as eolymp_dot_course_dot_assignment__v2__pb2
from eolymp.course import module_item_pb2 as eolymp_dot_course_dot_module__item__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/course/assignment_service_v2.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a&eolymp/course/assignment_item_v2.proto\x1a!eolymp/course/assignment_v2.proto\x1a\x1f\x65olymp/course/module_item.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa4\x01\n\x17\x43reateAssignmentV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12/\n\x0bstart_after\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18# \x01(\r\"\x1a\n\x18\x43reateAssignmentV2Output\",\n\x17\x44\x65leteAssignmentV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteAssignmentV2Output\"+\n\x16StartAssignmentV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x19\n\x17StartAssignmentV2Output\"\x18\n\x16ListAssignmentsV2Input\"E\n\x17ListAssignmentsV2Output\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.course.AssignmentV2\"/\n\x1aListAssignmentItemsV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"M\n\x1bListAssignmentItemsV2Output\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x1f.eolymp.course.AssignmentItemV2\"t\n\x1d\x44\x65scribeAssignmentItemV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x0f\n\x07item_id\x18\x02 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.ModuleItem.Extra\"O\n\x1e\x44\x65scribeAssignmentItemV2Output\x12-\n\x04item\x18\x01 \x01(\x0b\x32\x1f.eolymp.course.AssignmentItemV2\"\xfe\x01\n\x1bUpdateAssignmentItemV2Input\x12?\n\x05patch\x18\x01 \x03(\x0e\x32\x30.eolymp.course.UpdateAssignmentItemV2Input.Patch\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12\x0f\n\x07item_id\x18\x03 \x01(\t\x12-\n\x04item\x18\x04 \x01(\x0b\x32\x1f.eolymp.course.AssignmentItemV2\"K\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x45XCUSED\x10\x01\x12\x12\n\x0eGRADE_OVERRIDE\x10\x02\x12\x18\n\x14GRADE_OVERRIDE_RESET\x10\x03\"\x1e\n\x1cUpdateAssignmentItemV2Output\"@\n\x1aResetAssignmentItemV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x0f\n\x07item_id\x18\x02 \x01(\t\"\x1d\n\x1bResetAssignmentItemV2Output2\xf5\x0b\n\x13\x41ssignmentServiceV2\x12\xa3\x01\n\x10\x43reateAssignment\x12&.eolymp.course.CreateAssignmentV2Input\x1a\'.eolymp.course.CreateAssignmentV2Output\">\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/assignments\x12\xaf\x01\n\x10\x44\x65leteAssignment\x12&.eolymp.course.DeleteAssignmentV2Input\x1a\'.eolymp.course.DeleteAssignmentV2Output\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1a*\x18/assignments/{module_id}\x12\xb1\x01\n\x0fStartAssignment\x12%.eolymp.course.StartAssignmentV2Input\x1a&.eolymp.course.StartAssignmentV2Output\"O\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02 *\x1e/assignments/{module_id}/start\x12\x9f\x01\n\x0fListAssignments\x12%.eolymp.course.ListAssignmentsV2Input\x1a&.eolymp.course.ListAssignmentsV2Output\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/assignments\x12\xbd\x01\n\x13ListAssignmentItems\x12).eolymp.course.ListAssignmentItemsV2Input\x1a*.eolymp.course.ListAssignmentItemsV2Output\"O\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02 \x12\x1e/assignments/{module_id}/items\x12\xd0\x01\n\x16\x44\x65scribeAssignmentItem\x12,.eolymp.course.DescribeAssignmentItemV2Input\x1a-.eolymp.course.DescribeAssignmentItemV2Output\"Y\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\x12(/assignments/{module_id}/items/{item_id}\x12\xcb\x01\n\x14UpdateAssignmentItem\x12*.eolymp.course.UpdateAssignmentItemV2Input\x1a+.eolymp.course.UpdateAssignmentItemV2Output\"Z\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\"(/assignments/{module_id}/items/{item_id}\x12\xce\x01\n\x13ResetAssignmentItem\x12).eolymp.course.ResetAssignmentItemV2Input\x1a*.eolymp.course.ResetAssignmentItemV2Output\"`\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x30\"./assignments/{module_id}/items/{item_id}/resetB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.assignment_service_v2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ASSIGNMENTSERVICEV2.methods_by_name['CreateAssignment']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['CreateAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\"\014/assignments'
  _ASSIGNMENTSERVICEV2.methods_by_name['DeleteAssignment']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['DeleteAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\032*\030/assignments/{module_id}'
  _ASSIGNMENTSERVICEV2.methods_by_name['StartAssignment']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['StartAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002 *\036/assignments/{module_id}/start'
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignments']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignments']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\022\014/assignments'
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignmentItems']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignmentItems']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002 \022\036/assignments/{module_id}/items'
  _ASSIGNMENTSERVICEV2.methods_by_name['DescribeAssignmentItem']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['DescribeAssignmentItem']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\022(/assignments/{module_id}/items/{item_id}'
  _ASSIGNMENTSERVICEV2.methods_by_name['UpdateAssignmentItem']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['UpdateAssignmentItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\"(/assignments/{module_id}/items/{item_id}'
  _ASSIGNMENTSERVICEV2.methods_by_name['ResetAssignmentItem']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['ResetAssignmentItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0020\"./assignments/{module_id}/items/{item_id}/reset'
  _CREATEASSIGNMENTV2INPUT._serialized_start=301
  _CREATEASSIGNMENTV2INPUT._serialized_end=465
  _CREATEASSIGNMENTV2OUTPUT._serialized_start=467
  _CREATEASSIGNMENTV2OUTPUT._serialized_end=493
  _DELETEASSIGNMENTV2INPUT._serialized_start=495
  _DELETEASSIGNMENTV2INPUT._serialized_end=539
  _DELETEASSIGNMENTV2OUTPUT._serialized_start=541
  _DELETEASSIGNMENTV2OUTPUT._serialized_end=567
  _STARTASSIGNMENTV2INPUT._serialized_start=569
  _STARTASSIGNMENTV2INPUT._serialized_end=612
  _STARTASSIGNMENTV2OUTPUT._serialized_start=614
  _STARTASSIGNMENTV2OUTPUT._serialized_end=639
  _LISTASSIGNMENTSV2INPUT._serialized_start=641
  _LISTASSIGNMENTSV2INPUT._serialized_end=665
  _LISTASSIGNMENTSV2OUTPUT._serialized_start=667
  _LISTASSIGNMENTSV2OUTPUT._serialized_end=736
  _LISTASSIGNMENTITEMSV2INPUT._serialized_start=738
  _LISTASSIGNMENTITEMSV2INPUT._serialized_end=785
  _LISTASSIGNMENTITEMSV2OUTPUT._serialized_start=787
  _LISTASSIGNMENTITEMSV2OUTPUT._serialized_end=864
  _DESCRIBEASSIGNMENTITEMV2INPUT._serialized_start=866
  _DESCRIBEASSIGNMENTITEMV2INPUT._serialized_end=982
  _DESCRIBEASSIGNMENTITEMV2OUTPUT._serialized_start=984
  _DESCRIBEASSIGNMENTITEMV2OUTPUT._serialized_end=1063
  _UPDATEASSIGNMENTITEMV2INPUT._serialized_start=1066
  _UPDATEASSIGNMENTITEMV2INPUT._serialized_end=1320
  _UPDATEASSIGNMENTITEMV2INPUT_PATCH._serialized_start=1245
  _UPDATEASSIGNMENTITEMV2INPUT_PATCH._serialized_end=1320
  _UPDATEASSIGNMENTITEMV2OUTPUT._serialized_start=1322
  _UPDATEASSIGNMENTITEMV2OUTPUT._serialized_end=1352
  _RESETASSIGNMENTITEMV2INPUT._serialized_start=1354
  _RESETASSIGNMENTITEMV2INPUT._serialized_end=1418
  _RESETASSIGNMENTITEMV2OUTPUT._serialized_start=1420
  _RESETASSIGNMENTITEMV2OUTPUT._serialized_end=1449
  _ASSIGNMENTSERVICEV2._serialized_start=1452
  _ASSIGNMENTSERVICEV2._serialized_end=2977
# @@protoc_insertion_point(module_scope)



from eolymp.executor import usage_pb2 as _usage_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Report(_message.Message):
    __slots__ = ["actors", "agent_name", "error", "origin", "reference", "runs", "state", "version"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Actor(_message.Message):
        __slots__ = ["error_code", "error_message", "name", "signature"]
        class Error(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
        ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
        INIT_ERROR: Report.Actor.Error
        INTERNAL: Report.Actor.Error
        NAME_FIELD_NUMBER: _ClassVar[int]
        NONE: Report.Actor.Error
        SIGNATURE_FIELD_NUMBER: _ClassVar[int]
        error_code: Report.Actor.Error
        error_message: str
        name: str
        signature: str
        def __init__(self, name: _Optional[str] = ..., signature: _Optional[str] = ..., error_code: _Optional[_Union[Report.Actor.Error, str]] = ..., error_message: _Optional[str] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ["error_message", "reference", "state", "steps"]
        ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        STATE_FIELD_NUMBER: _ClassVar[int]
        STEPS_FIELD_NUMBER: _ClassVar[int]
        error_message: str
        reference: str
        state: Report.State
        steps: _containers.RepeatedCompositeFieldContainer[Report.Step]
        def __init__(self, reference: _Optional[str] = ..., state: _Optional[_Union[Report.State, str]] = ..., error_message: _Optional[str] = ..., steps: _Optional[_Iterable[_Union[Report.Step, _Mapping]]] = ...) -> None: ...
    class Step(_message.Message):
        __slots__ = ["execute", "group", "name", "outcome", "upload"]
        class Outcome(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        class Execute(_message.Message):
            __slots__ = ["actor", "cpu_time_limit", "cpu_time_usage", "exit_code", "exit_status", "memory_limit", "memory_usage", "resource_usage", "signal", "values", "wall_time_limit", "wall_time_usage"]
            class Exit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
                __slots__ = []
            class ValuesEntry(_message.Message):
                __slots__ = ["key", "value"]
                KEY_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                key: str
                value: str
                def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
            ACTOR_FIELD_NUMBER: _ClassVar[int]
            CPU_EXHAUSTED: Report.Step.Execute.Exit
            CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
            CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
            EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
            EXIT_STATUS_FIELD_NUMBER: _ClassVar[int]
            MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
            MEMORY_OVERFLOW: Report.Step.Execute.Exit
            MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
            RESOURCE_USAGE_FIELD_NUMBER: _ClassVar[int]
            RUNTIME_ERROR: Report.Step.Execute.Exit
            SIGNAL_FIELD_NUMBER: _ClassVar[int]
            SKIPPED: Report.Step.Execute.Exit
            SUCCESS: Report.Step.Execute.Exit
            TIMEOUT: Report.Step.Execute.Exit
            UNSPECIFIED: Report.Step.Execute.Exit
            VALUES_FIELD_NUMBER: _ClassVar[int]
            WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
            WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
            actor: str
            cpu_time_limit: int
            cpu_time_usage: int
            exit_code: int
            exit_status: Report.Step.Execute.Exit
            memory_limit: int
            memory_usage: int
            resource_usage: _usage_pb2.ResourceUsage
            signal: int
            values: _containers.ScalarMap[str, str]
            wall_time_limit: int
            wall_time_usage: int
            def __init__(self, actor: _Optional[str] = ..., exit_status: _Optional[_Union[Report.Step.Execute.Exit, str]] = ..., values: _Optional[_Mapping[str, str]] = ..., wall_time_usage: _Optional[int] = ..., wall_time_limit: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_usage: _Optional[int] = ..., memory_limit: _Optional[int] = ..., exit_code: _Optional[int] = ..., signal: _Optional[int] = ..., resource_usage: _Optional[_Union[_usage_pb2.ResourceUsage, _Mapping]] = ...) -> None: ...
        class Group(_message.Message):
            __slots__ = ["processes"]
            PROCESSES_FIELD_NUMBER: _ClassVar[int]
            processes: _containers.RepeatedCompositeFieldContainer[Report.Step.Execute]
            def __init__(self, processes: _Optional[_Iterable[_Union[Report.Step.Execute, _Mapping]]] = ...) -> None: ...
        class Upload(_message.Message):
            __slots__ = ["target_name", "target_url"]
            TARGET_NAME_FIELD_NUMBER: _ClassVar[int]
            TARGET_URL_FIELD_NUMBER: _ClassVar[int]
            target_name: str
            target_url: str
            def __init__(self, target_name: _Optional[str] = ..., target_url: _Optional[str] = ...) -> None: ...
        COMPLETE: Report.Step.Outcome
        EXECUTE_FIELD_NUMBER: _ClassVar[int]
        FAILED: Report.Step.Outcome
        GROUP_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OUTCOME_FIELD_NUMBER: _ClassVar[int]
        UNSPECIFIED: Report.Step.Outcome
        UPLOAD_FIELD_NUMBER: _ClassVar[int]
        execute: Report.Step.Execute
        group: Report.Step.Group
        name: str
        outcome: Report.Step.Outcome
        upload: Report.Step.Upload
        def __init__(self, name: _Optional[str] = ..., outcome: _Optional[_Union[Report.Step.Outcome, str]] = ..., execute: _Optional[_Union[Report.Step.Execute, _Mapping]] = ..., upload: _Optional[_Union[Report.Step.Upload, _Mapping]] = ..., group: _Optional[_Union[Report.Step.Group, _Mapping]] = ...) -> None: ...
    ACTORS_FIELD_NUMBER: _ClassVar[int]
    AGENT_NAME_FIELD_NUMBER: _ClassVar[int]
    BLOCKED: Report.State
    COMPLETE: Report.State
    ERROR_FIELD_NUMBER: _ClassVar[int]
    EXECUTING: Report.State
    FAILED: Report.State
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PENDING: Report.State
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    SKIPPED: Report.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    UNSPECIFIED: Report.State
    VERSION_FIELD_NUMBER: _ClassVar[int]
    actors: _containers.RepeatedCompositeFieldContainer[Report.Actor]
    agent_name: str
    error: str
    origin: str
    reference: str
    runs: _containers.RepeatedCompositeFieldContainer[Report.Run]
    state: Report.State
    version: int
    def __init__(self, reference: _Optional[str] = ..., origin: _Optional[str] = ..., agent_name: _Optional[str] = ..., version: _Optional[int] = ..., state: _Optional[_Union[Report.State, str]] = ..., actors: _Optional[_Iterable[_Union[Report.Actor, _Mapping]]] = ..., runs: _Optional[_Iterable[_Union[Report.Run, _Mapping]]] = ..., error: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class AchievementServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateAchievement(self, request, **kwargs):
        path = "/achievements"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.CreateAchievementOutput"),
            **kwargs,
        )

    def UpdateAchievement(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.UpdateAchievementOutput"),
            **kwargs,
        )

    def DeleteAchievement(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.DeleteAchievementOutput"),
            **kwargs,
        )

    def DescribeAchievement(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.DescribeAchievementOutput"),
            **kwargs,
        )

    def ListAchievements(self, request, **kwargs):
        path = "/achievements"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.ListAchievementsOutput"),
            **kwargs,
        )

    def DescribeAchievementTranslation(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.DescribeAchievementTranslationOutput"),
            **kwargs,
        )

    def ListAchievementTranslations(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.ListAchievementTranslationsOutput"),
            **kwargs,
        )

    def CreateAchievementTranslation(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)+"/translations"

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.CreateAchievementTranslationOutput"),
            **kwargs,
        )

    def UpdateAchievementTranslation(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.UpdateAchievementTranslationOutput"),
            **kwargs,
        )

    def DeleteAchievementTranslation(self, request, **kwargs):
        path = "/achievements/"+urllib.parse.quote(request.achievement_id)+"/translations/"+urllib.parse.quote(request.translation_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.achievement_id = ""
        request.translation_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.reward.DeleteAchievementTranslationOutput"),
            **kwargs,
        )




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Runtime(_message.Message):
    __slots__ = ["deprecated", "id", "lang", "name", "version"]
    DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LANG_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    deprecated: bool
    id: str
    lang: str
    name: str
    version: str
    def __init__(self, id: _Optional[str] = ..., lang: _Optional[str] = ..., version: _Optional[str] = ..., name: _Optional[str] = ..., deprecated: bool = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import entry_pb2 as _entry_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateEntryInput(_message.Message):
    __slots__ = ["entry"]
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    entry: _entry_pb2.Entry
    def __init__(self, entry: _Optional[_Union[_entry_pb2.Entry, _Mapping]] = ...) -> None: ...

class CreateEntryOutput(_message.Message):
    __slots__ = ["entry_id"]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    entry_id: str
    def __init__(self, entry_id: _Optional[str] = ...) -> None: ...

class DeleteEntryInput(_message.Message):
    __slots__ = ["entry_id"]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    entry_id: str
    def __init__(self, entry_id: _Optional[str] = ...) -> None: ...

class DeleteEntryOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeEntryInput(_message.Message):
    __slots__ = ["entry_id", "extra"]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    entry_id: str
    extra: _containers.RepeatedScalarFieldContainer[_entry_pb2.Entry.Extra]
    def __init__(self, entry_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_entry_pb2.Entry.Extra, str]]] = ...) -> None: ...

class DescribeEntryOutput(_message.Message):
    __slots__ = ["entry"]
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    entry: _entry_pb2.Entry
    def __init__(self, entry: _Optional[_Union[_entry_pb2.Entry, _Mapping]] = ...) -> None: ...

class DescribeTreeInput(_message.Message):
    __slots__ = ["depth", "draft", "extra", "root_id"]
    DEPTH_FIELD_NUMBER: _ClassVar[int]
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    ROOT_ID_FIELD_NUMBER: _ClassVar[int]
    depth: int
    draft: bool
    extra: _containers.RepeatedScalarFieldContainer[_entry_pb2.Entry.Extra]
    root_id: str
    def __init__(self, root_id: _Optional[str] = ..., depth: _Optional[int] = ..., draft: bool = ..., extra: _Optional[_Iterable[_Union[_entry_pb2.Entry.Extra, str]]] = ...) -> None: ...

class DescribeTreeOutput(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_entry_pb2.Entry]
    def __init__(self, items: _Optional[_Iterable[_Union[_entry_pb2.Entry, _Mapping]]] = ...) -> None: ...

class ListEntriesInput(_message.Message):
    __slots__ = ["extra", "filters", "offset", "order", "size", "sort"]
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["draft", "id", "parent_id", "query", "title"]
        DRAFT_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        PARENT_ID_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        draft: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        parent_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        query: str
        title: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., parent_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., draft: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., title: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    DEFAULT: ListEntriesInput.Sortable
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_entry_pb2.Entry.Extra]
    filters: ListEntriesInput.Filter
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListEntriesInput.Sortable
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListEntriesInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListEntriesInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., extra: _Optional[_Iterable[_Union[_entry_pb2.Entry.Extra, str]]] = ...) -> None: ...

class ListEntriesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_entry_pb2.Entry]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_entry_pb2.Entry, _Mapping]]] = ...) -> None: ...

class ListParentsInput(_message.Message):
    __slots__ = ["entry_id", "extra"]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    entry_id: str
    extra: _containers.RepeatedScalarFieldContainer[_entry_pb2.Entry.Extra]
    def __init__(self, entry_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_entry_pb2.Entry.Extra, str]]] = ...) -> None: ...

class ListParentsOutput(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_entry_pb2.Entry]
    def __init__(self, items: _Optional[_Iterable[_Union[_entry_pb2.Entry, _Mapping]]] = ...) -> None: ...

class MoveEntryInput(_message.Message):
    __slots__ = ["entry_id", "index", "parent_id"]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    entry_id: str
    index: int
    parent_id: str
    def __init__(self, entry_id: _Optional[str] = ..., parent_id: _Optional[str] = ..., index: _Optional[int] = ...) -> None: ...

class MoveEntryOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RenameEntryInput(_message.Message):
    __slots__ = ["entry_id", "title"]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    entry_id: str
    title: str
    def __init__(self, entry_id: _Optional[str] = ..., title: _Optional[str] = ...) -> None: ...

class RenameEntryOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateEntryInput(_message.Message):
    __slots__ = ["entry", "entry_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateEntryInput.Patch
    CONTENT_ALL: UpdateEntryInput.Patch
    DRAFT: UpdateEntryInput.Patch
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_URL: UpdateEntryInput.Patch
    SECTION_DESCRIPTION: UpdateEntryInput.Patch
    SECTION_IMAGE: UpdateEntryInput.Patch
    TITLE: UpdateEntryInput.Patch
    VIDEO_IMAGE_URL: UpdateEntryInput.Patch
    VIDEO_VIDEO_URL: UpdateEntryInput.Patch
    WEIGHT: UpdateEntryInput.Patch
    entry: _entry_pb2.Entry
    entry_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateEntryInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateEntryInput.Patch, str]]] = ..., entry_id: _Optional[str] = ..., entry: _Optional[_Union[_entry_pb2.Entry, _Mapping]] = ...) -> None: ...

class UpdateEntryOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ["description", "draft", "id", "image_url", "index", "name", "url"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_RENDER: Module.Extra
    DESCRIPTION_VALUE: Module.Extra
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EXTRA: Module.Extra
    URL_FIELD_NUMBER: _ClassVar[int]
    description: _content_pb2.Content
    draft: bool
    id: str
    image_url: str
    index: int
    name: str
    url: str
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., draft: bool = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., index: _Optional[int] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompleteMultipartUploadInput(_message.Message):
    __slots__ = ["parts", "upload_id"]
    class Part(_message.Message):
        __slots__ = ["checksum_md5", "checksum_sha1", "checksum_sha256", "etag", "number"]
        CHECKSUM_MD5_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_SHA1_FIELD_NUMBER: _ClassVar[int]
        CHECKSUM_SHA256_FIELD_NUMBER: _ClassVar[int]
        ETAG_FIELD_NUMBER: _ClassVar[int]
        NUMBER_FIELD_NUMBER: _ClassVar[int]
        checksum_md5: str
        checksum_sha1: str
        checksum_sha256: str
        etag: str
        number: int
        def __init__(self, number: _Optional[int] = ..., etag: _Optional[str] = ..., checksum_md5: _Optional[str] = ..., checksum_sha1: _Optional[str] = ..., checksum_sha256: _Optional[str] = ...) -> None: ...
    PARTS_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    parts: _containers.RepeatedCompositeFieldContainer[CompleteMultipartUploadInput.Part]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., parts: _Optional[_Iterable[_Union[CompleteMultipartUploadInput.Part, _Mapping]]] = ...) -> None: ...

class CompleteMultipartUploadOutput(_message.Message):
    __slots__ = ["file_id"]
    FILE_ID_FIELD_NUMBER: _ClassVar[int]
    file_id: str
    def __init__(self, file_id: _Optional[str] = ...) -> None: ...

class StartMultipartUploadInput(_message.Message):
    __slots__ = ["name", "type"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    def __init__(self, type: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class StartMultipartUploadOutput(_message.Message):
    __slots__ = ["upload_id"]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ...) -> None: ...

class UploadFileInput(_message.Message):
    __slots__ = ["checksum_md5", "checksum_sha1", "checksum_sha256", "data", "name", "type"]
    CHECKSUM_MD5_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_SHA1_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_SHA256_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    checksum_md5: str
    checksum_sha1: str
    checksum_sha256: str
    data: bytes
    name: str
    type: str
    def __init__(self, type: _Optional[str] = ..., name: _Optional[str] = ..., checksum_md5: _Optional[str] = ..., checksum_sha1: _Optional[str] = ..., checksum_sha256: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadFileOutput(_message.Message):
    __slots__ = ["file_id"]
    FILE_ID_FIELD_NUMBER: _ClassVar[int]
    file_id: str
    def __init__(self, file_id: _Optional[str] = ...) -> None: ...

class UploadPartInput(_message.Message):
    __slots__ = ["data", "part_number", "upload_id"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PART_NUMBER_FIELD_NUMBER: _ClassVar[int]
    UPLOAD_ID_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    part_number: int
    upload_id: str
    def __init__(self, upload_id: _Optional[str] = ..., part_number: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...

class UploadPartOutput(_message.Message):
    __slots__ = ["etag"]
    ETAG_FIELD_NUMBER: _ClassVar[int]
    etag: str
    def __init__(self, etag: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/assignment_item_v2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/course/assignment_item_v2.proto\x12\reolymp.course\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbc\x01\n\x10\x41ssignmentItemV2\x12\x16\n\x0emodule_item_id\x18\x02 \x01(\t\x12\x10\n\x08progress\x18\n \x01(\x02\x12\r\n\x05grade\x18\x0f \x01(\r\x12\x0f\n\x07\x65xcused\x18\x10 \x01(\x08\x12\x17\n\x0fgrade_automatic\x18\x11 \x01(\r\x12\x16\n\x0egrade_override\x18\x12 \x01(\r\x12-\n\tgraded_at\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.TimestampB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.assignment_item_v2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ASSIGNMENTITEMV2._serialized_start=91
  _ASSIGNMENTITEMV2._serialized_end=279
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/post_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import post_pb2 as eolymp_dot_discussion_dot_post__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/discussion/post_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/discussion/post.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"c\n\x11\x44\x65scribePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18< \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\";\n\x12\x44\x65scribePostOutput\x12%\n\x04post\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\"\x88\x08\n\x0eListPostsInput\x12\r\n\x05\x61\x66ter\x18\n \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06offset\x18\x0c \x01(\x05\x12\x34\n\x04sort\x18\x32 \x01(\x0e\x32&.eolymp.discussion.ListPostsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.discussion.ListPostsInput.Filter\x12\x0e\n\x06locale\x18< \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\x1a\xff\x04\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tsource_id\x18\r \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07type_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x39\n\ncreated_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12;\n\x0cpublished_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12/\n\x05\x64raft\x18\x0e \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06public\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nmoderation\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06locale\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12/\n\x05label\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"k\n\x04Sort\x12\x10\n\x0cUNKNOWN_SORT\x10\x00\x12\x10\n\x0cPUBLISHED_AT\x10\x01\x12\x0e\n\nCREATED_AT\x10\x02\x12\x0e\n\nVOTE_COUNT\x10\x03\x12\x0f\n\x0bREPLY_COUNT\x10\x04\x12\x0e\n\nPOPULARITY\x10\x05\"b\n\x0fListPostsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.discussion.Post\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"8\n\x0f\x43reatePostInput\x12%\n\x04post\x18\x01 \x01(\x0b\x32\x17.eolymp.discussion.Post\"#\n\x10\x43reatePostOutput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"\xe1\x01\n\x0fUpdatePostInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.discussion.UpdatePostInput.Patch\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12%\n\x04post\x18\x03 \x01(\x0b\x32\x17.eolymp.discussion.Post\"]\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\n\n\x06LABELS\x10\x02\x12\x0b\n\x07TYPE_ID\x10\x03\x12\n\n\x06LOCALE\x10\x04\x12\t\n\x05\x44RAFT\x10\x05\x12\x0e\n\nMODERATION\x10\x06\"\x12\n\x10UpdatePostOutput\"\"\n\x0f\x44\x65letePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\"\x12\n\x10\x44\x65letePostOutput\".\n\rVotePostInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"$\n\x0eVotePostOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\"v\n\x1c\x44\x65scribePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\"Y\n\x1d\x44\x65scribePostTranslationOutput\x12\x38\n\x0btranslation\x18\x01 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"\xb6\x02\n\x19ListPostTranslationsInput\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x44\n\x07\x66ilters\x18( \x01(\x0b\x32\x33.eolymp.discussion.ListPostTranslationsInput.Filter\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.discussion.Post.Extra\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"_\n\x1aListPostTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.eolymp.discussion.Post.Translation\"g\n\x1a\x43reatePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x38\n\x0btranslation\x18\x02 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"5\n\x1b\x43reatePostTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xfa\x01\n\x1aUpdatePostTranslationInput\x12\x42\n\x05patch\x18\x01 \x03(\x0e\x32\x33.eolymp.discussion.UpdatePostTranslationInput.Patch\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12\x38\n\x0btranslation\x18\x04 \x01(\x0b\x32#.eolymp.discussion.Post.Translation\"5\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\n\n\x06LABELS\x10\x02\x12\n\n\x06LOCALE\x10\x04\"\x1d\n\x1bUpdatePostTranslationOutput\"E\n\x1a\x44\x65letePostTranslationInput\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65letePostTranslationOutput2\xf6\x0f\n\x0bPostService\x12\xa1\x01\n\x0c\x44\x65scribePost\x12$.eolymp.discussion.DescribePostInput\x1a%.eolymp.discussion.DescribePostOutput\"D\x82\xe3\n\x18\x8a\xe3\n\x14\x64iscussion:post:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x12\x12\x10/posts/{post_id}\x12\x8d\x01\n\tListPosts\x12!.eolymp.discussion.ListPostsInput\x1a\".eolymp.discussion.ListPostsOutput\"9\x82\xe3\n\x18\x8a\xe3\n\x14\x64iscussion:post:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/posts\x12\x91\x01\n\nCreatePost\x12\".eolymp.discussion.CreatePostInput\x1a#.eolymp.discussion.CreatePostOutput\":\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x08\"\x06/posts\x12\x9b\x01\n\nUpdatePost\x12\".eolymp.discussion.UpdatePostInput\x1a#.eolymp.discussion.UpdatePostOutput\"D\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x12\x1a\x10/posts/{post_id}\x12\x9b\x01\n\nDeletePost\x12\".eolymp.discussion.DeletePostInput\x1a#.eolymp.discussion.DeletePostOutput\"D\x82\xe3\n\x19\x8a\xe3\n\x15\x64iscussion:post:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x12*\x10/posts/{post_id}\x12\x9d\x01\n\x08VotePost\x12 .eolymp.discussion.VotePostInput\x1a!.eolymp.discussion.VotePostOutput\"L\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17\"\x15/posts/{post_id}/vote\x12\xe4\x01\n\x17\x44\x65scribePostTranslation\x12/.eolymp.discussion.DescribePostTranslationInput\x1a\x30.eolymp.discussion.DescribePostTranslationOutput\"f\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x30\x12./posts/{post_id}/translations/{translation_id}\x12\xc9\x01\n\x14ListPostTranslations\x12,.eolymp.discussion.ListPostTranslationsInput\x1a-.eolymp.discussion.ListPostTranslationsOutput\"T\x82\xe3\n\x1c\x8a\xe3\n\x18typewriter:fragment:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1f\x12\x1d/posts/{post_id}/translations\x12\xcd\x01\n\x15\x43reatePostTranslation\x12-.eolymp.discussion.CreatePostTranslationInput\x1a..eolymp.discussion.CreatePostTranslationOutput\"U\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1f\"\x1d/posts/{post_id}/translations\x12\xde\x01\n\x15UpdatePostTranslation\x12-.eolymp.discussion.UpdatePostTranslationInput\x1a..eolymp.discussion.UpdatePostTranslationOutput\"f\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x30\x1a./posts/{post_id}/translations/{translation_id}\x12\xde\x01\n\x15\x44\x65letePostTranslation\x12-.eolymp.discussion.DeletePostTranslationInput\x1a..eolymp.discussion.DeletePostTranslationOutput\"f\x82\xe3\n\x1d\x8a\xe3\n\x19typewriter:fragment:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x30*./posts/{post_id}/translations/{translation_id}B7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.post_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _POSTSERVICE.methods_by_name['DescribePost']._options = None
  _POSTSERVICE.methods_by_name['DescribePost']._serialized_options = b'\202\343\n\030\212\343\n\024discussion:post:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\022\022\020/posts/{post_id}'
  _POSTSERVICE.methods_by_name['ListPosts']._options = None
  _POSTSERVICE.methods_by_name['ListPosts']._serialized_options = b'\202\343\n\030\212\343\n\024discussion:post:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\010\022\006/posts'
  _POSTSERVICE.methods_by_name['CreatePost']._options = None
  _POSTSERVICE.methods_by_name['CreatePost']._serialized_options = b'\202\343\n\031\212\343\n\025discussion:post:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\010\"\006/posts'
  _POSTSERVICE.methods_by_name['UpdatePost']._options = None
  _POSTSERVICE.methods_by_name['UpdatePost']._serialized_options = b'\202\343\n\031\212\343\n\025discussion:post:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\022\032\020/posts/{post_id}'
  _POSTSERVICE.methods_by_name['DeletePost']._options = None
  _POSTSERVICE.methods_by_name['DeletePost']._serialized_options = b'\202\343\n\031\212\343\n\025discussion:post:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\022*\020/posts/{post_id}'
  _POSTSERVICE.methods_by_name['VotePost']._options = None
  _POSTSERVICE.methods_by_name['VotePost']._serialized_options = b'\202\343\n\034\212\343\n\030discussion:message:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027\"\025/posts/{post_id}/vote'
  _POSTSERVICE.methods_by_name['DescribePostTranslation']._options = None
  _POSTSERVICE.methods_by_name['DescribePostTranslation']._serialized_options = b'\202\343\n\034\212\343\n\030typewriter:fragment:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\0020\022./posts/{post_id}/translations/{translation_id}'
  _POSTSERVICE.methods_by_name['ListPostTranslations']._options = None
  _POSTSERVICE.methods_by_name['ListPostTranslations']._serialized_options = b'\202\343\n\034\212\343\n\030typewriter:fragment:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\037\022\035/posts/{post_id}/translations'
  _POSTSERVICE.methods_by_name['CreatePostTranslation']._options = None
  _POSTSERVICE.methods_by_name['CreatePostTranslation']._serialized_options = b'\202\343\n\035\212\343\n\031typewriter:fragment:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\037\"\035/posts/{post_id}/translations'
  _POSTSERVICE.methods_by_name['UpdatePostTranslation']._options = None
  _POSTSERVICE.methods_by_name['UpdatePostTranslation']._serialized_options = b'\202\343\n\035\212\343\n\031typewriter:fragment:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\0020\032./posts/{post_id}/translations/{translation_id}'
  _POSTSERVICE.methods_by_name['DeletePostTranslation']._options = None
  _POSTSERVICE.methods_by_name['DeletePostTranslation']._serialized_options = b'\202\343\n\035\212\343\n\031typewriter:fragment:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\0020*./posts/{post_id}/translations/{translation_id}'
  _DESCRIBEPOSTINPUT._serialized_start=257
  _DESCRIBEPOSTINPUT._serialized_end=356
  _DESCRIBEPOSTOUTPUT._serialized_start=358
  _DESCRIBEPOSTOUTPUT._serialized_end=417
  _LISTPOSTSINPUT._serialized_start=420
  _LISTPOSTSINPUT._serialized_end=1452
  _LISTPOSTSINPUT_FILTER._serialized_start=704
  _LISTPOSTSINPUT_FILTER._serialized_end=1343
  _LISTPOSTSINPUT_SORT._serialized_start=1345
  _LISTPOSTSINPUT_SORT._serialized_end=1452
  _LISTPOSTSOUTPUT._serialized_start=1454
  _LISTPOSTSOUTPUT._serialized_end=1552
  _CREATEPOSTINPUT._serialized_start=1554
  _CREATEPOSTINPUT._serialized_end=1610
  _CREATEPOSTOUTPUT._serialized_start=1612
  _CREATEPOSTOUTPUT._serialized_end=1647
  _UPDATEPOSTINPUT._serialized_start=1650
  _UPDATEPOSTINPUT._serialized_end=1875
  _UPDATEPOSTINPUT_PATCH._serialized_start=1782
  _UPDATEPOSTINPUT_PATCH._serialized_end=1875
  _UPDATEPOSTOUTPUT._serialized_start=1877
  _UPDATEPOSTOUTPUT._serialized_end=1895
  _DELETEPOSTINPUT._serialized_start=1897
  _DELETEPOSTINPUT._serialized_end=1931
  _DELETEPOSTOUTPUT._serialized_start=1933
  _DELETEPOSTOUTPUT._serialized_end=1951
  _VOTEPOSTINPUT._serialized_start=1953
  _VOTEPOSTINPUT._serialized_end=1999
  _VOTEPOSTOUTPUT._serialized_start=2001
  _VOTEPOSTOUTPUT._serialized_end=2037
  _DESCRIBEPOSTTRANSLATIONINPUT._serialized_start=2039
  _DESCRIBEPOSTTRANSLATIONINPUT._serialized_end=2157
  _DESCRIBEPOSTTRANSLATIONOUTPUT._serialized_start=2159
  _DESCRIBEPOSTTRANSLATIONOUTPUT._serialized_end=2248
  _LISTPOSTTRANSLATIONSINPUT._serialized_start=2251
  _LISTPOSTTRANSLATIONSINPUT._serialized_end=2561
  _LISTPOSTTRANSLATIONSINPUT_FILTER._serialized_start=2444
  _LISTPOSTTRANSLATIONSINPUT_FILTER._serialized_end=2561
  _LISTPOSTTRANSLATIONSOUTPUT._serialized_start=2563
  _LISTPOSTTRANSLATIONSOUTPUT._serialized_end=2658
  _CREATEPOSTTRANSLATIONINPUT._serialized_start=2660
  _CREATEPOSTTRANSLATIONINPUT._serialized_end=2763
  _CREATEPOSTTRANSLATIONOUTPUT._serialized_start=2765
  _CREATEPOSTTRANSLATIONOUTPUT._serialized_end=2818
  _UPDATEPOSTTRANSLATIONINPUT._serialized_start=2821
  _UPDATEPOSTTRANSLATIONINPUT._serialized_end=3071
  _UPDATEPOSTTRANSLATIONINPUT_PATCH._serialized_start=3018
  _UPDATEPOSTTRANSLATIONINPUT_PATCH._serialized_end=3071
  _UPDATEPOSTTRANSLATIONOUTPUT._serialized_start=3073
  _UPDATEPOSTTRANSLATIONOUTPUT._serialized_end=3102
  _DELETEPOSTTRANSLATIONINPUT._serialized_start=3104
  _DELETEPOSTTRANSLATIONINPUT._serialized_end=3173
  _DELETEPOSTTRANSLATIONOUTPUT._serialized_start=3175
  _DELETEPOSTTRANSLATIONOUTPUT._serialized_end=3204
  _POSTSERVICE._serialized_start=3207
  _POSTSERVICE._serialized_end=5245
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/entry_section.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/course/entry_section.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\"B\n\x07Section\x12\r\n\x05image\x18\x01 \x01(\t\x12(\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x13.eolymp.ecm.ContentB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.entry_section_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _SECTION._serialized_start=78
  _SECTION._serialized_end=144
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/assignment_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import assignment_pb2 as eolymp_dot_course_dot_assignment__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/course/assignment_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/course/assignment.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xbf\x03\n\x14ListAssignmentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListAssignmentsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.course.ListAssignmentsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Assignment.Extra\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x0c \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"P\n\x15ListAssignmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.Assignment\"a\n\x17\x44\x65scribeAssignmentInput\x12\x15\n\rassignment_id\x18\x01 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Assignment.Extra\"I\n\x18\x44\x65scribeAssignmentOutput\x12-\n\nassignment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Assignment\"\x1b\n\x19IntrospectAssignmentInput\"K\n\x1aIntrospectAssignmentOutput\x12-\n\nassignment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Assignment\"F\n\x15\x43reateAssignmentInput\x12-\n\nassignment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Assignment\"/\n\x16\x43reateAssignmentOutput\x12\x15\n\rassignment_id\x18\x01 \x01(\t\"\xe9\x01\n\x15UpdateAssignmentInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.course.UpdateAssignmentInput.Patch\x12\x15\n\rassignment_id\x18\x02 \x01(\t\x12-\n\nassignment\x18\x03 \x01(\x0b\x32\x19.eolymp.course.Assignment\"O\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0f\n\x0bSTART_AFTER\x10\x01\x12\x13\n\x0f\x43OMPLETE_BEFORE\x10\x02\x12\x0c\n\x08\x44URATION\x10\x03\x12\t\n\x05ITEMS\x10\x04\"\x18\n\x16UpdateAssignmentOutput\".\n\x15\x44\x65leteAssignmentInput\x12\x15\n\rassignment_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteAssignmentOutput\"(\n\x14StartAssignmentInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\"\x17\n\x15StartAssignmentOutput2\x9e\t\n\x11\x41ssignmentService\x12\x9f\x01\n\x10\x43reateAssignment\x12$.eolymp.course.CreateAssignmentInput\x1a%.eolymp.course.CreateAssignmentOutput\">\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x1a\x0c/assignments\x12\xaf\x01\n\x10UpdateAssignment\x12$.eolymp.course.UpdateAssignmentInput\x1a%.eolymp.course.UpdateAssignmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/assignments/{assignment_id}\x12\xaf\x01\n\x10\x44\x65leteAssignment\x12$.eolymp.course.DeleteAssignmentInput\x1a%.eolymp.course.DeleteAssignmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/assignments/{assignment_id}\x12\xb4\x01\n\x12\x44\x65scribeAssignment\x12&.eolymp.course.DescribeAssignmentInput\x1a\'.eolymp.course.DescribeAssignmentOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/assignments/{assignment_id}\x12\xb0\x01\n\x14IntrospectAssignment\x12(.eolymp.course.IntrospectAssignmentInput\x1a).eolymp.course.IntrospectAssignmentOutput\"C\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\x12\x12/viewer/assignment\x12\x9b\x01\n\x0fListAssignments\x12#.eolymp.course.ListAssignmentsInput\x1a$.eolymp.course.ListAssignmentsOutput\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/assignments\x12{\n\x0fStartAssignment\x12#.eolymp.course.StartAssignmentInput\x1a$.eolymp.course.StartAssignmentOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x08\"\x06/startB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.assignment_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ASSIGNMENTSERVICE.methods_by_name['CreateAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['CreateAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\032\014/assignments'
  _ASSIGNMENTSERVICE.methods_by_name['UpdateAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['UpdateAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/assignments/{assignment_id}'
  _ASSIGNMENTSERVICE.methods_by_name['DeleteAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['DeleteAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/assignments/{assignment_id}'
  _ASSIGNMENTSERVICE.methods_by_name['DescribeAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['DescribeAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/assignments/{assignment_id}'
  _ASSIGNMENTSERVICE.methods_by_name['IntrospectAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['IntrospectAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\024\022\022/viewer/assignment'
  _ASSIGNMENTSERVICE.methods_by_name['ListAssignments']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['ListAssignments']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/assignments'
  _ASSIGNMENTSERVICE.methods_by_name['StartAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['StartAssignment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\010\"\006/start'
  _LISTASSIGNMENTSINPUT._serialized_start=258
  _LISTASSIGNMENTSINPUT._serialized_end=705
  _LISTASSIGNMENTSINPUT_FILTER._serialized_start=527
  _LISTASSIGNMENTSINPUT_FILTER._serialized_end=680
  _LISTASSIGNMENTSINPUT_SORTABLE._serialized_start=682
  _LISTASSIGNMENTSINPUT_SORTABLE._serialized_end=705
  _LISTASSIGNMENTSOUTPUT._serialized_start=707
  _LISTASSIGNMENTSOUTPUT._serialized_end=787
  _DESCRIBEASSIGNMENTINPUT._serialized_start=789
  _DESCRIBEASSIGNMENTINPUT._serialized_end=886
  _DESCRIBEASSIGNMENTOUTPUT._serialized_start=888
  _DESCRIBEASSIGNMENTOUTPUT._serialized_end=961
  _INTROSPECTASSIGNMENTINPUT._serialized_start=963
  _INTROSPECTASSIGNMENTINPUT._serialized_end=990
  _INTROSPECTASSIGNMENTOUTPUT._serialized_start=992
  _INTROSPECTASSIGNMENTOUTPUT._serialized_end=1067
  _CREATEASSIGNMENTINPUT._serialized_start=1069
  _CREATEASSIGNMENTINPUT._serialized_end=1139
  _CREATEASSIGNMENTOUTPUT._serialized_start=1141
  _CREATEASSIGNMENTOUTPUT._serialized_end=1188
  _UPDATEASSIGNMENTINPUT._serialized_start=1191
  _UPDATEASSIGNMENTINPUT._serialized_end=1424
  _UPDATEASSIGNMENTINPUT_PATCH._serialized_start=1345
  _UPDATEASSIGNMENTINPUT_PATCH._serialized_end=1424
  _UPDATEASSIGNMENTOUTPUT._serialized_start=1426
  _UPDATEASSIGNMENTOUTPUT._serialized_end=1450
  _DELETEASSIGNMENTINPUT._serialized_start=1452
  _DELETEASSIGNMENTINPUT._serialized_end=1498
  _DELETEASSIGNMENTOUTPUT._serialized_start=1500
  _DELETEASSIGNMENTOUTPUT._serialized_end=1524
  _STARTASSIGNMENTINPUT._serialized_start=1526
  _STARTASSIGNMENTINPUT._serialized_end=1566
  _STARTASSIGNMENTOUTPUT._serialized_start=1568
  _STARTASSIGNMENTOUTPUT._serialized_end=1591
  _ASSIGNMENTSERVICE._serialized_start=1594
  _ASSIGNMENTSERVICE._serialized_end=2776
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module_item_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import module_item_pb2 as eolymp_dot_course_dot_module__item__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/course/module_item_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/course/module_item.proto\x1a eolymp/wellknown/direction.proto\"@\n\x15\x43reateModuleItemInput\x12\'\n\x04item\x18\x01 \x01(\x0b\x32\x19.eolymp.course.ModuleItem\")\n\x16\x43reateModuleItemOutput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"\xf2\x01\n\x15UpdateModuleItemInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.course.UpdateModuleItemInput.Patch\x12\x0f\n\x07item_id\x18\x02 \x01(\t\x12\'\n\x04item\x18\x03 \x01(\x0b\x32\x19.eolymp.course.ModuleItem\"d\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\t\n\x05\x44\x45PTH\x10\x05\x12\x0b\n\x07\x43ONTENT\x10\x06\x12\x0b\n\x07GRADING\x10\x07\"\x18\n\x16UpdateModuleItemOutput\"c\n\x13MoveModuleItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x15\n\rnew_module_id\x18\x02 \x01(\t\x12\x11\n\tnew_index\x18\x03 \x01(\r\x12\x11\n\tnew_depth\x18\x04 \x01(\r\"\x16\n\x14MoveModuleItemOutput\"(\n\x15\x44\x65leteModuleItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteModuleItemOutput\"[\n\x17\x44\x65scribeModuleItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.ModuleItem.Extra\"C\n\x18\x44\x65scribeModuleItemOutput\x12\'\n\x04item\x18\x01 \x01(\x0b\x32\x19.eolymp.course.ModuleItem\"\xb2\x02\n\x14ListModuleItemsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListModuleItemsInput.Filter\x12\x36\n\x04sort\x18\x32 \x01(\x0e\x32(.eolymp.course.ListModuleItemsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.ModuleItem.Extra\x1a\x17\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\"P\n\x15ListModuleItemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.ModuleItem2\xe3\x07\n\x11ModuleItemService\x12\x99\x01\n\x10\x43reateModuleItem\x12$.eolymp.course.CreateModuleItemInput\x1a%.eolymp.course.CreateModuleItemOutput\"8\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x08\"\x06/items\x12\xa3\x01\n\x10UpdateModuleItem\x12$.eolymp.course.UpdateModuleItemInput\x1a%.eolymp.course.UpdateModuleItemOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\x1a\x10/items/{item_id}\x12\xa2\x01\n\x0eMoveModuleItem\x12\".eolymp.course.MoveModuleItemInput\x1a#.eolymp.course.MoveModuleItemOutput\"G\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x17\"\x15/items/{item_id}/move\x12\xa3\x01\n\x10\x44\x65leteModuleItem\x12$.eolymp.course.DeleteModuleItemInput\x1a%.eolymp.course.DeleteModuleItemOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12*\x10/items/{item_id}\x12\xa8\x01\n\x12\x44\x65scribeModuleItem\x12&.eolymp.course.DescribeModuleItemInput\x1a\'.eolymp.course.DescribeModuleItemOutput\"A\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x12\x12\x10/items/{item_id}\x12\x95\x01\n\x0fListModuleItems\x12#.eolymp.course.ListModuleItemsInput\x1a$.eolymp.course.ListModuleItemsOutput\"7\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/itemsB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_item_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULEITEMSERVICE.methods_by_name['CreateModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['CreateModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\010\"\006/items'
  _MODULEITEMSERVICE.methods_by_name['UpdateModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['UpdateModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\022\032\020/items/{item_id}'
  _MODULEITEMSERVICE.methods_by_name['MoveModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['MoveModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\027\"\025/items/{item_id}/move'
  _MODULEITEMSERVICE.methods_by_name['DeleteModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['DeleteModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\022*\020/items/{item_id}'
  _MODULEITEMSERVICE.methods_by_name['DescribeModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['DescribeModuleItem']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\022\022\020/items/{item_id}'
  _MODULEITEMSERVICE.methods_by_name['ListModuleItems']._options = None
  _MODULEITEMSERVICE.methods_by_name['ListModuleItems']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\010\022\006/items'
  _CREATEMODULEITEMINPUT._serialized_start=224
  _CREATEMODULEITEMINPUT._serialized_end=288
  _CREATEMODULEITEMOUTPUT._serialized_start=290
  _CREATEMODULEITEMOUTPUT._serialized_end=331
  _UPDATEMODULEITEMINPUT._serialized_start=334
  _UPDATEMODULEITEMINPUT._serialized_end=576
  _UPDATEMODULEITEMINPUT_PATCH._serialized_start=476
  _UPDATEMODULEITEMINPUT_PATCH._serialized_end=576
  _UPDATEMODULEITEMOUTPUT._serialized_start=578
  _UPDATEMODULEITEMOUTPUT._serialized_end=602
  _MOVEMODULEITEMINPUT._serialized_start=604
  _MOVEMODULEITEMINPUT._serialized_end=703
  _MOVEMODULEITEMOUTPUT._serialized_start=705
  _MOVEMODULEITEMOUTPUT._serialized_end=727
  _DELETEMODULEITEMINPUT._serialized_start=729
  _DELETEMODULEITEMINPUT._serialized_end=769
  _DELETEMODULEITEMOUTPUT._serialized_start=771
  _DELETEMODULEITEMOUTPUT._serialized_end=795
  _DESCRIBEMODULEITEMINPUT._serialized_start=797
  _DESCRIBEMODULEITEMINPUT._serialized_end=888
  _DESCRIBEMODULEITEMOUTPUT._serialized_start=890
  _DESCRIBEMODULEITEMOUTPUT._serialized_end=957
  _LISTMODULEITEMSINPUT._serialized_start=960
  _LISTMODULEITEMSINPUT._serialized_end=1266
  _LISTMODULEITEMSINPUT_FILTER._serialized_start=1224
  _LISTMODULEITEMSINPUT_FILTER._serialized_end=1247
  _LISTMODULEITEMSINPUT_SORT._serialized_start=1249
  _LISTMODULEITEMSINPUT_SORT._serialized_end=1266
  _LISTMODULEITEMSOUTPUT._serialized_start=1268
  _LISTMODULEITEMSOUTPUT._serialized_end=1348
  _MODULEITEMSERVICE._serialized_start=1351
  _MODULEITEMSERVICE._serialized_end=2346
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/configuration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/atlas/configuration_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\";\n\x15\x43onfigurePolygonInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x18\n\x16\x43onfigurePolygonOutput\"\x16\n\x14\x44\x65scribePolygonInput\"?\n\x15\x44\x65scribePolygonOutput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x14\n\x0cpassword_set\x18\x02 \x01(\x08\x32\xda\x02\n\x14\x43onfigurationService\x12\xa1\x01\n\x10\x43onfigurePolygon\x12#.eolymp.atlas.ConfigurePolygonInput\x1a$.eolymp.atlas.ConfigurePolygonOutput\"B\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x11\x1a\x0f/config/polygon\x12\x9d\x01\n\x0f\x44\x65scribePolygon\x12\".eolymp.atlas.DescribePolygonInput\x1a#.eolymp.atlas.DescribePolygonOutput\"A\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x11\x12\x0f/config/polygonB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.configuration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CONFIGURATIONSERVICE.methods_by_name['ConfigurePolygon']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['ConfigurePolygon']._serialized_options = b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\021\032\017/config/polygon'
  _CONFIGURATIONSERVICE.methods_by_name['DescribePolygon']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['DescribePolygon']._serialized_options = b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\021\022\017/config/polygon'
  _CONFIGUREPOLYGONINPUT._serialized_start=157
  _CONFIGUREPOLYGONINPUT._serialized_end=216
  _CONFIGUREPOLYGONOUTPUT._serialized_start=218
  _CONFIGUREPOLYGONOUTPUT._serialized_end=242
  _DESCRIBEPOLYGONINPUT._serialized_start=244
  _DESCRIBEPOLYGONINPUT._serialized_end=266
  _DESCRIBEPOLYGONOUTPUT._serialized_start=268
  _DESCRIBEPOLYGONOUTPUT._serialized_end=331
  _CONFIGURATIONSERVICE._serialized_start=334
  _CONFIGURATIONSERVICE._serialized_end=680
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/stats.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import usage_pb2 as eolymp_dot_executor_dot_usage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/executor/stats.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/usage.proto\"\xc7\x02\n\x05Stats\x12\x11\n\tstdin_url\x18\x01 \x01(\t\x12\x12\n\nstdout_url\x18\x02 \x01(\t\x12\x12\n\nstderr_url\x18\x03 \x01(\t\x12\x15\n\roverall_usage\x18\n \x01(\x02\x12\x1a\n\x12wall_time_duration\x18\x14 \x01(\r\x12\x17\n\x0fwall_time_usage\x18\x15 \x01(\x02\x12\x19\n\x11\x63pu_time_duration\x18\x19 \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x1a \x01(\x02\x12\x13\n\x0bmemory_peak\x18\x1e \x01(\x04\x12\x14\n\x0cmemory_usage\x18\x1f \x01(\x02\x12\x36\n\x0eresource_usage\x18\x32 \x01(\x0b\x32\x1e.eolymp.executor.ResourceUsage\x12\x11\n\texit_code\x18\x64 \x01(\r\x12\x0e\n\x06signal\x18\x65 \x01(\rB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.stats_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _STATS._serialized_start=78
  _STATS._serialized_end=405
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Fragment(_message.Message):
    __slots__ = ["content", "created_at", "id", "labels", "locale", "path", "public", "title", "updated_at"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_RENDER: Fragment.Extra
    CONTENT_VALUE: Fragment.Extra
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    NO_EXTRA: Fragment.Extra
    PATH_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    content: _content_pb2.Content
    created_at: _timestamp_pb2.Timestamp
    id: str
    labels: _containers.RepeatedScalarFieldContainer[str]
    locale: str
    path: str
    public: bool
    title: str
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., path: _Optional[str] = ..., locale: _Optional[str] = ..., title: _Optional[str] = ..., public: bool = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...



from .content_service_pb2 import *
from .render_service_pb2 import *
from .content_service_http import *
from .fragment_pb2 import *
from .events_pb2 import *
from .variant_pb2 import *
from .render_service_http import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class AssignmentServiceV2Client:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateAssignment(self, request, **kwargs):
        path = "/assignments"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.CreateAssignmentV2Output"),
            **kwargs,
        )

    def DeleteAssignment(self, request, **kwargs):
        path = "/assignments/"+urllib.parse.quote(request.module_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.module_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DeleteAssignmentV2Output"),
            **kwargs,
        )

    def StartAssignment(self, request, **kwargs):
        path = "/assignments/"+urllib.parse.quote(request.module_id)+"/start"

        # Cleanup URL parameters to avoid any ambiguity
        request.module_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.StartAssignmentV2Output"),
            **kwargs,
        )

    def ListAssignments(self, request, **kwargs):
        path = "/assignments"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListAssignmentsV2Output"),
            **kwargs,
        )

    def ListAssignmentItems(self, request, **kwargs):
        path = "/assignments/"+urllib.parse.quote(request.module_id)+"/items"

        # Cleanup URL parameters to avoid any ambiguity
        request.module_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ListAssignmentItemsV2Output"),
            **kwargs,
        )

    def DescribeAssignmentItem(self, request, **kwargs):
        path = "/assignments/"+urllib.parse.quote(request.module_id)+"/items/"+urllib.parse.quote(request.item_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.module_id = ""
        request.item_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.DescribeAssignmentItemV2Output"),
            **kwargs,
        )

    def UpdateAssignmentItem(self, request, **kwargs):
        path = "/assignments/"+urllib.parse.quote(request.module_id)+"/items/"+urllib.parse.quote(request.item_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.module_id = ""
        request.item_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.UpdateAssignmentItemV2Output"),
            **kwargs,
        )

    def ResetAssignmentItem(self, request, **kwargs):
        path = "/assignments/"+urllib.parse.quote(request.module_id)+"/items/"+urllib.parse.quote(request.item_id)+"/reset"

        # Cleanup URL parameters to avoid any ambiguity
        request.module_id = ""
        request.item_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.course.ResetAssignmentItemV2Output"),
            **kwargs,
        )




from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AssignmentV2(_message.Message):
    __slots__ = ["assigned_at", "complete_before", "completed_at", "duration", "grade", "module_id", "progress", "start_after", "started_at", "status"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: AssignmentV2.Status
    ASSIGNED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETE: AssignmentV2.Status
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    GRADE_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    READY: AssignmentV2.Status
    SCHEDULED: AssignmentV2.Status
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    START_AFTER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UNASSIGNED: AssignmentV2.Status
    UNKNOWN_STATUS: AssignmentV2.Status
    UPSOLVE: AssignmentV2.Status
    assigned_at: _timestamp_pb2.Timestamp
    complete_before: _timestamp_pb2.Timestamp
    completed_at: _timestamp_pb2.Timestamp
    duration: int
    grade: int
    module_id: str
    progress: float
    start_after: _timestamp_pb2.Timestamp
    started_at: _timestamp_pb2.Timestamp
    status: AssignmentV2.Status
    def __init__(self, module_id: _Optional[str] = ..., status: _Optional[_Union[AssignmentV2.Status, str]] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., assigned_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., grade: _Optional[int] = ..., progress: _Optional[float] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AssignmentItemV2(_message.Message):
    __slots__ = ["excused", "grade", "grade_automatic", "grade_override", "graded_at", "module_item_id", "progress"]
    EXCUSED_FIELD_NUMBER: _ClassVar[int]
    GRADED_AT_FIELD_NUMBER: _ClassVar[int]
    GRADE_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    GRADE_FIELD_NUMBER: _ClassVar[int]
    GRADE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    MODULE_ITEM_ID_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    excused: bool
    grade: int
    grade_automatic: int
    grade_override: int
    graded_at: _timestamp_pb2.Timestamp
    module_item_id: str
    progress: float
    def __init__(self, module_item_id: _Optional[str] = ..., progress: _Optional[float] = ..., grade: _Optional[int] = ..., excused: bool = ..., grade_automatic: _Optional[int] = ..., grade_override: _Optional[int] = ..., graded_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class TicketServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateTicket(self, request, **kwargs):
        path = "/tickets"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateTicketOutput"),
            **kwargs,
        )

    def UpdateTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateTicketOutput"),
            **kwargs,
        )

    def ReadTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/read"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ReadTicketOutput"),
            **kwargs,
        )

    def DeleteTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteTicketOutput"),
            **kwargs,
        )

    def DescribeTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeTicketOutput"),
            **kwargs,
        )

    def ListTickets(self, request, **kwargs):
        path = "/tickets"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListTicketsOutput"),
            **kwargs,
        )

    def ReplyTicket(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ReplyTicketOutput"),
            **kwargs,
        )

    def ListReplies(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies"

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListRepliesOutput"),
            **kwargs,
        )

    def DeleteReply(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies/"+urllib.parse.quote(request.reply_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""
        request.reply_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteReplyOutput"),
            **kwargs,
        )

    def UpdateReply(self, request, **kwargs):
        path = "/tickets/"+urllib.parse.quote(request.ticket_id)+"/replies/"+urllib.parse.quote(request.reply_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.ticket_id = ""
        request.reply_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateReplyOutput"),
            **kwargs,
        )

